# What are the steps of DOE?

Obtaining good results from a DOE involves these seven steps:

1. Set objectives
2. Select process variables
3. Select an experimental design
4. Execute the design
5. Check that the data are consistent with the experimental assumptions
6. Analyze and interpret the results
7. Use/present the results (may lead to further runs or DOE's).

## Practical Considerations

Important practical considerations in planning and running experiments are

* Check performance of gauges/measurement devices first.
* Keep the experiment as simple as possible.
* Check that all planned runs are feasible.
* Watch out for process drifts and shifts during the run.
* Avoid unplanned changes (e.g., swap operators at halfway point).
* Allow some time (and back-up material) for unexpected events.
* Obtain buy-in from all parties involved.
* Maintain effective ownership of each step in the experimental plan.
* Preserve all the raw data--do not keep only summary averages!
* Record everything that happens.
* Reset equipment to its original state after the experiment.

## The Sequential or Iterative Approach to DOE

It is often a mistake to believe that one big experiment will give the answer.

A more useful approach to experimental design is to recognize that while one experiment might provide a useful result, it is more common to perform two or three, or maybe more, experiments before a complete answer is attained. In other words, an iterative approach is best and, in the end, most economical. Putting all one's eggs in one basket is not advisable.

The reason an iterative approach frequently works best is because it is logical to move through stages of experimentation, each stage providing insight as to how the next experiment should be run.